.. role:: hidden
    :class: hidden-section

ax.benchmark
===================================

.. automodule:: ax.benchmark
.. currentmodule:: ax.benchmark

Benchmark
----------------

Benchmark Method
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.benchmark_method
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problem
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.benchmark_problem
    :members:
    :undoc-members:
    :show-inheritance:


Benchmark Result
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.benchmark_result
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark
~~~~~~~~~

.. automodule:: ax.benchmark.benchmark
    :members:
    :undoc-members:
    :show-inheritance:

Scored Benchmark
~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.scored_benchmark
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Methods GPEI and MOO
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.methods.gpei_and_moo
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Methods Modular BoTorch
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.methods.modular_botorch
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Methods SAASBO
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.methods.saasbo
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Methods Choose Generation Strategy
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.methods.choose_generation_strategy
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems Registry
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.registry
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems High Dimensional Embedding
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.hd_embedding
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems Surrogate
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.surrogate
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems Jenatton
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.synthetic.hss.jenatton
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems PyTorchCNN
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.hpo.pytorch_cnn
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems PyTorchCNN TorchVision
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.hpo.torchvision
    :members:
    :undoc-members:
    :show-inheritance:
